Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(284)

Unified Diff: components/exo/keyboard.h

Issue 2396883003: exo: Fix dragging edge cases (Closed)
Patch Set: Rebase Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | components/exo/keyboard.cc » ('j') | components/exo/shell_surface.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/exo/keyboard.h
diff --git a/components/exo/keyboard.h b/components/exo/keyboard.h
index b56834fca6c09f088a2cfb7f56ac86e5989a005e..ed184dfd01d6368cfd764154403bd85ea5e6866d 100644
--- a/components/exo/keyboard.h
+++ b/components/exo/keyboard.h
@@ -27,7 +27,7 @@ class Surface;
class Keyboard : public ui::EventHandler,
public WMHelper::FocusObserver,
public WMHelper::InputDeviceEventObserver,
- public WMHelper::MaximizeModeObserver,
+ public WMHelper::ShellObserver,
public SurfaceObserver {
public:
explicit Keyboard(KeyboardDelegate* delegate);
@@ -50,7 +50,7 @@ class Keyboard : public ui::EventHandler,
// Overridden from ui::InputDeviceEventObserver:
void OnKeyboardDeviceConfigurationChanged() override;
// Overridden from WMHelper::MaximizeModeObserver:
void OnMaximizeModeStarted() override;
void OnMaximizeModeEnded() override;
« no previous file with comments | « no previous file | components/exo/keyboard.cc » ('j') | components/exo/shell_surface.cc » ('J')
@@ -50,7 +50,7 @@ class Keyboard : public ui::EventHandler,
// Overridden from ui::InputDeviceEventObserver:
void OnKeyboardDeviceConfigurationChanged() override;
- // Overridden from WMHelper::MaximizeModeObserver:
+ // Overridden from WMHelper::ShellObserver:
void OnMaximizeModeStarted() override;
void OnMaximizeModeEnded() override;

Powered by Google App Engine
This is Rietveld 408576698